@@ -56,4 +56,29 @@ EquityIndexFuture = setRefClass("EquityIndexFuture",
                          callSuper(...,TradeType='Index')
                        }
                        
-                     ))
\ No newline at end of file
+                     ))
+
+#' 
+#' Creates an Equity Option object with the relevant info needed to calculate the Exposure-at-Default (EAD)
+#' @title Equity Option Class
+#' @param Notional The notional amount of the trade
+#' @docType NULL
+#' @param MTM      The mark-to-market valuation of the trade
+#' @param Currency The currency set that the trade belongs to
+#' @param Si The number of years that the trade will take to start (zero if already started)
+#' @param Ei The number of years that the trade will expire
+#' @param BuySell Takes the values of either 'Buy' or 'Sell'
+#' @param traded_price the price that trade was done
+#' @return An object of type EquityOption
+#' @export
+#' @author Tasos Grivas <tasos@@openriskcalculator.com>
+
+EquityOption = setRefClass("EquityOption",
+                                
+                                contains=c("Equity","Option"),
+                                methods = list(
+                                  initialize = function(...){
+                                    callSuper(...,TradeType='Index')
+                                  }
+                                  
+                                ))
